@@ -5,11 +5,12 @@ from .types import (
     PreProcessPaymentResponse,
     Payment,
     AccountInfo,
+    ALL_OPERATION_TYPES,
     IncomingTransaction
 )
 
 __all__ = (
-    'AccountInfo', 'OperationType', 'Operation',
+    'AccountInfo', 'OperationType', 'ALL_OPERATION_TYPES', 'Operation',
     'OperationDetails',
     'PreProcessPaymentResponse', 'Payment', 'IncomingTransaction'
 )
